@@ -1,6 +1,6 @@
 package Net::ISC::DHCPd::Config;
 
-=head1 NAME 
+=head1 NAME
 
 Net::ISC::DHCPd::Config - Parse and create ISC DHCPd config
 
@@ -57,7 +57,10 @@ This class does the role L<Net::ISC::DHCPd::Config::Root>.
 =head1 POSSIBLE CONFIG GRAPH
 
  Config
+  |- Config::Class
+  |- Config::SubClass
   |- Config::Include
+  |- Config::Conditional
   |- Config::Subnet
   |  |- Config::Option
   |  |- Config::Declaration
@@ -90,7 +93,7 @@ This class does the role L<Net::ISC::DHCPd::Config::Root>.
   |  '- Config::KeyValue
   |
   |- Config::OptionSpace
-  |  '- Config::OptionSpace::Option
+  |- Config::OptionCode
   |
   |- Config::Option
   |- Config::Declaration *
@@ -106,14 +109,20 @@ with 'Net::ISC::DHCPd::Config::Root';
 
 __PACKAGE__->create_children(qw/
     Net::ISC::DHCPd::Config::Host
+    Net::ISC::DHCPd::Config::Class
+    Net::ISC::DHCPd::Config::Conditional
+    Net::ISC::DHCPd::Config::SubClass
     Net::ISC::DHCPd::Config::Subnet
+    Net::ISC::DHCPd::Config::Subnet6
     Net::ISC::DHCPd::Config::SharedNetwork
     Net::ISC::DHCPd::Config::Function
     Net::ISC::DHCPd::Config::OptionSpace
+    Net::ISC::DHCPd::Config::OptionCode
     Net::ISC::DHCPd::Config::Option
     Net::ISC::DHCPd::Config::Include
     Net::ISC::DHCPd::Config::Key
     Net::ISC::DHCPd::Config::Group
+    Net::ISC::DHCPd::Config::Zone
     Net::ISC::DHCPd::Config::Block
     Net::ISC::DHCPd::Config::KeyValue
 /);
@@ -201,6 +210,18 @@ List of parsed L<Net::ISC::DHCPd::Config::Include> objects.
 See L<Net::ISC::DHCPd::Config::Role/children> for details on how to
 add, update or remove these objects.
 
+=head2 classes
+
+List of parsed L<Net::ISC::DHCPd::Config::Class> objects.
+See L<Net::ISC::DHCPd::Config::Role/children> for details on how to
+add, update or remove these objects.
+
+=head2 subclasses
+
+List of parsed L<Net::ISC::DHCPd::Config::SubClass> objects.
+See L<Net::ISC::DHCPd::Config::Role/children> for details on how to
+add, update or remove these objects.
+
 =head2 keyvalues
 
 List of parsed L<Net::ISC::DHCPd::Config::KeyValue> objects.
